@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provides musical cadence chords
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Music::Chord::Note;
 use Music::Scales;
@@ -87,7 +87,7 @@ Music::Cadence - Provides musical cadence chords
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -166,8 +166,8 @@ this is:
 
   CM: 1
   Dm: 2
-  EM: 3
-  Fm: 4
+  Em: 3
+  FM: 4
   GM: 5
   Am: 6
   Bo: 7
